@@ -1,8 +1,8 @@
 /* Include OpenCL header, and define OpenCL extensions, since what is and is not
  * available in the official headers is very system-dependent */
 
-#ifndef _EXT_H
-#define _EXT_H
+#ifndef EXT_H
+#define EXT_H
 
 /* We will use the deprecated clGetExtensionFunctionAddress,
  * so let the headers know that we don't care about it being deprecated.
@@ -222,4 +222,12 @@ typedef cl_ulong  cl_device_partition_property_ext;
 /* cl_intel_required_subgroup_size */
 #define CL_DEVICE_SUB_GROUP_SIZES_INTEL			0x4108
 
+/* clGeICDLoaderInfoOCLICD */
+typedef enum {
+	CL_ICDL_OCL_VERSION=1,
+	CL_ICDL_VERSION=2,
+	CL_ICDL_NAME=3,
+	CL_ICDL_VENDOR=4,
+} cl_icdl_info;
+
 #endif
